summary refs log tree commit diff
path: root/pkgs/development/web/plone/4.1.6.nix
diff options
context:
space:
mode:
Diffstat (limited to 'pkgs/development/web/plone/4.1.6.nix')
-rw-r--r--pkgs/development/web/plone/4.1.6.nix12
1 files changed, 6 insertions, 6 deletions
diff --git a/pkgs/development/web/plone/4.1.6.nix b/pkgs/development/web/plone/4.1.6.nix
index 23a0cc34f909..47bd00b80cbf 100644
--- a/pkgs/development/web/plone/4.1.6.nix
+++ b/pkgs/development/web/plone/4.1.6.nix
@@ -1,11 +1,11 @@
 # DO NOT EDIT THIS FILE!
 #
 # Nix expressions autogenerated with:
 #   bin/pypi2nix -n plone43Packages -d Plone -d mailinglogger -d zc.recipe.egg -d plone.recipe.zope2instance -d Pillow -i setuptools -i zc_buildout -i pillow -e plone/4.1.6.json -p plone/4.1.6.txt -o plone/4.1.6.nix
 
 { pkgs, pythonPackages }:
 
-let plone43Packages = pythonPackages.python.modules // rec {
+let plone41Packages = pythonPackages.python.modules // rec {
   inherit (pythonPackages) buildPythonPackage setuptools zc_buildout pillow;
   inherit (pkgs) fetchurl stdenv;
 
@@ -3092,10 +3092,10 @@ let plone43Packages = pythonPackages.python.modules // rec {
   };
 
   plone_recipe_zope2instance = buildPythonPackage rec {
-    name = "plone.recipe.zope2instance-4.1.9";
+    name = "plone.recipe.zope2instance-4.1.10";
     src = fetchurl {
-      url = "http://pypi.python.org/packages/source/p/plone.recipe.zope2instance/plone.recipe.zope2instance-4.1.9.zip";
-      md5 = "ad90efc7948107ab63efac46ab589569";
+      url = "http://pypi.python.org/packages/source/p/plone.recipe.zope2instance/plone.recipe.zope2instance-4.1.10.zip";
+      md5 = "787fad7fa44757de74a50a91e9bcfcb5";
     };
     buildInputs = [ pkgs.unzip ];
     propagatedBuildInputs = [ zc_buildout zc_recipe_egg mailinglogger setuptools zope2 ];
@@ -5138,4 +5138,4 @@ let plone43Packages = pythonPackages.python.modules // rec {
     };
   };
 
-}; in plone43Packages
+}; in plone41Packages
@@ -1,11 +1,11 @@
 #
 # Nix expressions autogenerated with:
-#   bin/pypi2nix -n plone43Packages -d Plone -d mailinglogger -d zc.recipe.egg -d plone.recipe.zope2instance -d Pillow -i setuptools -i zc_buildout -i pillow -e plone/4.1.6.json -p plone/4.1.6.txt -o plone/4.1.6.nix
+#   bin/pypi2nix -n plone41Packages -d Plone -d mailinglogger -d zc.recipe.egg -d plone.recipe.zope2instance -d Pillow -i setuptools -i zc_buildout -i pillow -e plone/4.1.6.json -p plone/4.1.6.txt -o plone/4.1.6.nix
 
 { pkgs, pythonPackages }: